@@ -1,4 +1,4 @@
 package T1;
 use Object::Simple( base => 'B1', mixins => ['M1'] );
 
-Object::Simple->end;
+Object::Simple->build_class;
